==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/iotoperationsorchestrator/kotlin/outputs/GetTargetResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * A Target resource belonging to an Instance resource.
 * @property components A list of components.
 * @property extendedLocation Edge location of the resource.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property reconciliationPolicy Reconciliation Policy.
 * @property scope Deployment scope (such as Kubernetes namespace).
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property topologies Defines the device topology for a target or instance.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 * @property version Version of the particular resource.
 */
public data class GetTargetResult(
    public val components: List<ComponentPropertiesResponse>? = null,
    public val extendedLocation: ExtendedLocationResponse,
    public val id: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val reconciliationPolicy: ReconciliationPolicyResponse? = null,
    public val scope: String? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val topologies: List<TopologiesPropertiesResponse>? = null,
    public val type: String,
    public val version: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.iotoperationsorchestrator.outputs.GetTargetResult):
            GetTargetResult = GetTargetResult(
            components = javaType.components().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.ComponentPropertiesResponse.Companion.toKotlin(args0)
                })
            }),
            extendedLocation = javaType.extendedLocation().let({ args0 ->
                com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.ExtendedLocationResponse.Companion.toKotlin(args0)
            }),
            id = javaType.id(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            reconciliationPolicy = javaType.reconciliationPolicy().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.ReconciliationPolicyResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            scope = javaType.scope().map({ args0 -> args0 }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            topologies = javaType.topologies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.TopologiesPropertiesResponse.Companion.toKotlin(args0)
                })
            }),
            type = javaType.type(),
            version = javaType.version().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/iotoperationsorchestrator/kotlin/outputs/GetTargetResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * A Target resource belonging to an Instance resource.
 * @property components A list of components.
 * @property extendedLocation Edge location of the resource.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property location The geo-location where the resource lives
 * @property name The name of the resource
 * @property provisioningState The status of the last operation.
 * @property reconciliationPolicy Reconciliation Policy.
 * @property scope Deployment scope (such as Kubernetes namespace).
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property topologies Defines the device topology for a target or instance.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 * @property version Version of the particular resource.
 */
public data class GetTargetResult(
    public val components: List<ComponentPropertiesResponse>? = null,
    public val extendedLocation: ExtendedLocationResponse,
    public val id: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val reconciliationPolicy: ReconciliationPolicyResponse? = null,
    public val scope: String? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val topologies: List<TopologiesPropertiesResponse>? = null,
    public val type: String,
    public val version: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.iotoperationsorchestrator.outputs.GetTargetResult): GetTargetResult = GetTargetResult(
            components = javaType.components().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.ComponentPropertiesResponse.Companion.toKotlin(args0)
                })
            }),
            extendedLocation = javaType.extendedLocation().let({ args0 ->
                com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.ExtendedLocationResponse.Companion.toKotlin(args0)
            }),
            id = javaType.id(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            reconciliationPolicy = javaType.reconciliationPolicy().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.ReconciliationPolicyResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            scope = javaType.scope().map({ args0 -> args0 }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            topologies = javaType.topologies().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsorchestrator.kotlin.outputs.TopologiesPropertiesResponse.Companion.toKotlin(args0)
                })
            }),
            type = javaType.type(),
            version = javaType.version().map({ args0 -> args0 }).orElse(null),
        )
    }
}
